exceptiontools.PartitionError
=============================

.. abjad-lineage:: abjad.tools.exceptiontools.PartitionError.PartitionError

.. autoclass:: abjad.tools.exceptiontools.PartitionError.PartitionError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.PartitionError.PartitionError.__unicode__
   :noindex:
